RainbowColors class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- amber → const Color
- amberAccent → const Color
- black → const Color
- blue → const Color
- blueAccent → const Color
- blueGrey → const Color
- brown → const Color
- cyan → const Color
- cyanAccent → const Color
- error → const Color
- green → const Color
- greenAccent → const Color
- grey → const Color
- indigo → const Color
- indigoAccent → const Color
- info → const Color
- lime → const Color
- limeAccent → const Color
- log → const Color
- orangeAccent → const Color
- pink → const Color
- pinkAccent → const Color
- purple → const Color
- purpleAccent → const Color
- red → const Color
- redAccent → const Color
- success → const Color
- teal → const Color
- tealAccent → const Color
- warning → const Color
- white → const Color
- yellow → const Color
- yellowAccent → const Color